@@ -59,8 +59,8 @@ API Reference
 #include "sqlite3.h"
 #endif
 
-#if SQLITE_VERSION_NUMBER < 3034000
-#error Your SQLite version is too old.  It must be at least 3.34
+#if SQLITE_VERSION_NUMBER < 3036000
+#error Your SQLite version is too old.  It must be at least 3.36
 #endif
 
 /* system headers */
@@ -71,6 +71,7 @@ API Reference
 #include "apswversion.h"
 
 /* Python headers */
+#define PY_SSIZE_T_CLEAN
 #include <Python.h>
 #include <pythread.h>
 #include "structmember.h"
@@ -1134,16 +1135,19 @@ formatsqlvalue(APSW_ARGUNUSED PyObject *self, PyObject *value)
 #endif
   )
   {
-    const unsigned char *buffer;
+    const void *buffer;
+    const char *bufferc = NULL;
     Py_ssize_t buflen;
     int asrb;
     PyObject *unires;
     Py_UNICODE *res;
-#define _HEXDIGITS
+    READBUFFERVARS;
 
-    asrb = PyObject_AsReadBuffer(value, (const void **)&buffer, &buflen);
+#define _HEXDIGITS
+    compat_PyObjectReadBuffer(value);
     APSW_FAULT_INJECT(FormatSQLValueAsReadBufferFails,
                       ,
+                      ENDREADBUFFER;
                       (PyErr_NoMemory(), asrb = -1));
     if (asrb != 0)
       return NULL;
@@ -1152,17 +1156,23 @@ formatsqlvalue(APSW_ARGUNUSED PyObject *self, PyObject *value)
                       unires = PyUnicode_FromUnicode(NULL, buflen * 2 + 3),
                       unires = PyErr_NoMemory());
     if (!unires)
+    {
+      ENDREADBUFFER;
       return NULL;
+    }
+    bufferc = buffer;
     res = PyUnicode_AS_UNICODE(unires);
     *res++ = 'X';
     *res++ = '\'';
     /* About the billionth time I have written a hex conversion routine */
     for (; buflen; buflen--)
     {
-      *res++ = "0123456789ABCDEF"[(*buffer) >> 4];
-      *res++ = "0123456789ABCDEF"[(*buffer++) & 0x0f];
+      *res++ = "0123456789ABCDEF"[(*bufferc) >> 4];
+      *res++ = "0123456789ABCDEF"[(*bufferc++) & 0x0f];
     }
     *res++ = '\'';
+
+    ENDREADBUFFER;
     APSW_Unicode_Return(unires);
   }
 
@@ -1826,6 +1836,8 @@ modules etc. For example::
         ADDINT(SQLITE_FCNTL_CKPT_DONE),
         ADDINT(SQLITE_FCNTL_CKPT_START),
         ADDINT(SQLITE_FCNTL_RESERVE_BYTES),
+        ADDINT(SQLITE_FCNTL_EXTERNAL_READER),
+        ADDINT(SQLITE_FCNTL_CKSM_FILE),
         END,
 
         DICT("mapping_conflict_resolution_modes"),
@@ -1857,8 +1869,7 @@ modules etc. For example::
         ADDINT(SQLITE_TXN_NONE),
         ADDINT(SQLITE_TXN_READ),
         ADDINT(SQLITE_TXN_WRITE),
-        END
-    };
+        END};
 
     for (i = 0; i < sizeof(integers) / sizeof(integers[0]); i++)
     {
